@@ -1,7 +1,9 @@
 package server
 
 import (
+	"bufio"
 	"errors"
+	"strings"
 
 	"github.com/emersion/go-imap"
 	"github.com/emersion/go-imap/backend"
@@ -253,6 +255,13 @@ func (cmd *Append) Handle(conn Conn) error {
 	}
 
 	if err := mbox.CreateMessage(cmd.Flags, cmd.Date, cmd.Message); err != nil {
+		if err == backend.ErrTooBig {
+			return ErrStatusResp(&imap.StatusResp{
+				Type: imap.StatusRespNo,
+				Code: "TOOBIG",
+				Info: "Message size exceeding limit",
+			})
+		}
 		return err
 	}
 
@@ -275,3 +284,41 @@ func (cmd *Append) Handle(conn Conn) error {
 
 	return nil
 }
+
+type Unselect struct {
+	commands.Unselect
+}
+
+func (cmd *Unselect) Handle(conn Conn) error {
+	ctx := conn.Context()
+	if ctx.Mailbox == nil {
+		return ErrNoMailboxSelected
+	}
+
+	ctx.Mailbox = nil
+	ctx.MailboxReadOnly = false
+	return nil
+}
+
+type Idle struct {
+	commands.Idle
+}
+
+func (cmd *Idle) Handle(conn Conn) error {
+	cont := &imap.ContinuationReq{Info: "idling"}
+	if err := conn.WriteResp(cont); err != nil {
+		return err
+	}
+
+	// Wait for DONE
+	scanner := bufio.NewScanner(conn)
+	scanner.Scan()
+	if err := scanner.Err(); err != nil {
+		return err
+	}
+
+	if strings.ToUpper(scanner.Text()) != "DONE" {
+		return errors.New("Expected DONE")
+	}
+	return nil
+}
